import React, { useState, useRef } from 'react';
import { Space, Table, Button, Image, Divider, Card, Input } from 'antd';
import type { InputRef } from 'antd';
import type { ColumnType, ColumnsType } from 'antd/es/table';
import type { FilterConfirmProps, TableRowSelection } from 'antd/es/table/interface';
import { t } from '@/utils/i18n';
import { PlusOutlined, ExclamationCircleFilled, DeleteOutlined, SearchOutlined } from '@ant-design/icons';
import { antdUtils } from '@/utils/antd';
import mData from '../../../../../mock/findMaterialPage.json'

const { Search } = Input;

interface Classify {
  id: number;
  classifyName: string;
}

interface DataType {
  id: number;
  createTime: string;
  classifyId: number;
  materialImgId: number;
  materialName: string;
  materialRemark: string;
  materialWidth: number;
  materialHeight: number;
  materialSize: number;
  createId: number;
  materialImgUrl: string;
  dictDetails: string[];
  classify: Classify;
}

type DataIndex = keyof DataType;

const filters = [
  {
    text: '全部素材',
    value: '1',
  },
  {
    text: '卡通',
    value: '2',
    children: [
      {
        text: '海贼王',
        value: '20',
      },
      {
        text: '火影忍者',
        value: '21',
      },
      {
        text: '死神',
        value: '22',
      },
    ],
  },
  {
    text: '风景',
    value: '3',
  },
  {
    text: '插图',
    value: '4',
  },
  {
    text: '模型',
    value: '5',
  },
  {
    text: '图标',
    value: '6',
  },
  {
    text: '其他',
    value: '52',
  },
]

//素材
const TablePage: React.FC = () => {

  const showDeleteConfirm = (item: DataType) => {
    antdUtils.modal?.confirm({
      title: `确认删除标题为: ${item.materialName} 的素材吗?`,
      icon: <ExclamationCircleFilled />,
      content: '请注意删除以后不可恢复！',
      okText: '删除',
      okType: 'danger',
      cancelText: '取消',
      onOk() {
        return new Promise((resolve, reject) => {
          setTimeout(() => {
            antdUtils.message?.open({
              type: 'success',
              content: '删除成功',
            });
            resolve(null)
          }, 1000);

        }).catch(() => antdUtils.message?.open({
          type: 'error',
          content: '操作失败',
        }));
      },
      onCancel() {
      },
    });
  };

  const [searchText, setSearchText] = useState('');
  const [searchedColumn, setSearchedColumn] = useState('');
  const searchInput = useRef<InputRef>(null);

  const [onSearching, setOnSearching] = useState(false);

  const handleSearch = (
    selectedKeys: string[],
    confirm: (param?: FilterConfirmProps) => void,
    dataIndex: DataIndex,
  ) => {
    setOnSearching(true);
    setTimeout(()=>{
      setOnSearching(false);
      confirm();
    }, 1000)
    // confirm();
    setSearchText(selectedKeys[0]);
    setSearchedColumn(dataIndex);
  };

  const handleReset = (clearFilters: () => void) => {
    clearFilters();
    setSearchText('');
  };

  const getColumnSearchProps = (dataIndex: DataIndex): ColumnType<DataType> => ({
    filterDropdown: ({ setSelectedKeys, selectedKeys, confirm, clearFilters, close }) => (
      <div style={{ padding: 8 }} onKeyDown={(e) => e.stopPropagation()}>
        <Search
          ref={searchInput}
          placeholder={"输入图片标题"}
          value={selectedKeys[0]}
          onChange={(e) => setSelectedKeys(e.target.value ? [e.target.value] : [])}
          onSearch={() => handleSearch(selectedKeys as string[], confirm, dataIndex)}
          allowClear
          style={{ marginBottom: 8, display: 'block' }}
          enterButton="搜索" 
          size="large" 
          loading={onSearching}
        />
      </div>
    ),
    filterIcon: (filtered: boolean) => (
      <SearchOutlined style={{ color: filtered ? '#1677ff' : undefined }} />
    ),
    onFilter: (value, record) =>
      record[dataIndex]
        .toString()
        .toLowerCase()
        .includes((value as string).toLowerCase()),
    onFilterDropdownOpenChange: (visible) => {
      if (visible) {
        setTimeout(() => searchInput.current?.select(), 100);
      }
    },
  });

  const columns: ColumnsType<DataType> = [
    {
      title: '图片',
      dataIndex: 'materialImgUrl',
      key: 'materialImgUrl',
      render: (value: string) => (
        <div className='flex justify-center'>
          {value ? (
            <Image src={value} className='w-[40px] h-[40px] flex items-center rounded-[50%]' />
          ) : null}
        </div>
      ),
      align: 'center',
      width: 100,
    },
    {
      title: '标题',
      dataIndex: 'materialName',
      key: 'materialName',
      width: 150,
      ...getColumnSearchProps('materialName'),
    },
    {
      title: '分类',
      dataIndex: ['classify', 'classifyName'],
      key: 'classify',
      width: 80,
      filters,
      filterMode: 'tree',
      filterSearch: false,
    },
    {
      title: '描述',
      key: 'materialRemark',
      dataIndex: 'materialRemark'
    },
    {
      title: '分辨率',
      key: 'materialInfo',
      render: (_, record) => (
        <>
          {record.materialWidth}px * {record.materialHeight}px
        </>
      ),
      width: 150,
    },
    {
      title: '图片大小',
      dataIndex: 'materialSize',
      key: 'materialRemark',
      render: (value: number) => (
        <>
          {value}kb
        </>
      ),
      width: 100,
    },
    {
      title: '上传时间',
      key: 'createTime',
      dataIndex: 'createTime',
      width: 200,
    },
    {
      title: t("QkOmYwne" /* 操作 */),
      key: 'action',
      render: (_, record) => (
        <Space size="middle" split={(
          <Divider type='vertical' />
        )}>
          <a
            onClick={() => {
              // setCreateVisible(true);
              // setCurRowData(record);
            }}>
            编辑
          </a>
          <a
            onClick={() => {
              showDeleteConfirm(record)
            }}>
            删除
          </a>
        </Space>
      ),
      width: 150,
    },
  ];



  const data: Array<DataType> = mData as Array<DataType>;

  const [isDisableDelete, setDisableDelete] = useState<boolean>(true)
  const [selectedRowKeys, setSelectedRowKeys] = useState<React.Key[]>([]);

  const onSelectChange = (newSelectedRowKeys: React.Key[]) => {
    console.log('selectedRowKeys changed: ', newSelectedRowKeys);
    setSelectedRowKeys(newSelectedRowKeys);
    setDisableDelete(newSelectedRowKeys.length === 0)
  };

  const rowSelection: TableRowSelection<DataType> = {
    selectedRowKeys,
    onChange: onSelectChange,
    selections: [
      Table.SELECTION_ALL,
      Table.SELECTION_INVERT,
      Table.SELECTION_NONE,
      {
        key: 'odd',
        text: '选择双数行',
        onSelect: (changeableRowKeys) => {
          let newSelectedRowKeys = [];
          newSelectedRowKeys = changeableRowKeys.filter((_, index) => {
            if (index % 2 !== 0) {
              return false;
            }
            return true;
          });
          setSelectedRowKeys(newSelectedRowKeys);
        },
      },
      {
        key: 'even',
        text: '选择单数行',
        onSelect: (changeableRowKeys) => {
          let newSelectedRowKeys = [];
          newSelectedRowKeys = changeableRowKeys.filter((_, index) => {
            if (index % 2 !== 0) {
              return true;
            }
            return false;
          });
          setSelectedRowKeys(newSelectedRowKeys);
        },
      },
    ],
  };

  return (
    <>
      <div className='flex flex-row'>
        <Card className='basis-1/4  w-[100px] mb-[10px] dark:bg-[rgb(33,41,70)] bg-white roundle-lg px[12px]'>
        </Card>
        <Card className='basis-3/4 mb-[10px] ml-[10px] dark:bg-[rgb(33,41,70)] bg-white roundle-lg px[12px]' bodyStyle={{
            paddingTop: 0,
            paddingBottom: 0
          }}>
          <div className="py-[8px] flex flex-row-reverse">
            <Button className="ml-5" danger size='middle' icon={<DeleteOutlined />} disabled={isDisableDelete}> 批量删除 </Button>
            <Button className="ml-5" type='primary' size='middle' icon={<PlusOutlined />}> 新增素材 </Button>
          </div>
          <Table rowKey="id" rowSelection={rowSelection} scroll={{ x: true }} columns={columns} dataSource={data} className='bg-transparent'
            pagination={{ position: ['bottomRight'] }}
          />
        </Card>
      </div>
    </>
  );
};

export default TablePage;
