import { Space, Table, Button, Input, Select, Divider, Tag, Card, Badge, Form } from 'antd';
import type { TableColumnsType } from 'antd';
import { t } from '@/utils/i18n';
import React, { useState, useEffect } from 'react';
import { PlusOutlined, ExclamationCircleFilled, SearchOutlined, UndoOutlined } from '@ant-design/icons';
import type { PositionVO } from '@/models'
import { antdUtils } from '@/utils/antd';
import { useRequest } from '@/hooks/use-request';
import positonService from '@/request/service/positon';
import { formatDate } from '@/utils/formatTime'
import PositionEditor from './create-position'

const MenuListPage: React.FC = () => {

    const [editorVisable, seEditorVisable] = useState<boolean>(false);
    const [editPosition, seEditPosition] = useState<PositionVO>();
    const [dataSource, setDataSource] = useState<PositionVO[]>([]);
    const [searchFrom] = Form.useForm();


    const { runAsync: getPostPageApi } = useRequest(positonService.getPostPageApi, { manual: true });
    const { runAsync: deletePostApi } = useRequest(positonService.deletePostApi, { manual: true });

    const load = async () => {
        const [error, { data }] = await getPostPageApi(searchFrom.getFieldsValue());
        if (!error) {
            setDataSource(data.list);
        }
    };


    const showDeleteConfirm = (menu: PositionVO) => {
        antdUtils.modal?.confirm({
            title: '确认要将该菜单删除吗？',
            icon: <ExclamationCircleFilled />,
            content: '请注意删除以后不可恢复！',
            okText: '删除',
            okType: 'danger',
            cancelText: '取消',
            onOk() {
                return new Promise(async (resolve) => {
                    const [error, { code, msg} ] = await deletePostApi({ id: menu.id });
                    if(error || code !== 0) {
                        antdUtils.message?.open({ type: 'error', content: msg??'操作失败'})
                    } else {
                        antdUtils.message?.open({ type: 'success', content: '删除成功'})
                    }
                    await load();
                    resolve('')
                }).catch(() => antdUtils.message?.open({
                    type: 'error',
                    content: '操作失败',
                }));
            },
            onCancel() {
            },
        });
    };


    const columns: TableColumnsType<PositionVO> = [
        {
            title: '岗位编号',
            dataIndex: 'id',
            key: 'id',
            align: 'center',
            width: 100,
        },
        {
            title: '岗位名称',
            dataIndex: 'name',
            key: 'name',
            align: 'right',
            width: 200,
        },
        {
            title: '岗位编码',
            dataIndex: 'code',
            key: 'code',
            align: 'center',
            width: 150
        },
        {
            title: '岗位顺序',
            key: 'sort',
            dataIndex: 'sort',
            align: 'center',
        },
        {
            title: '状态',
            key: 'status',
            dataIndex: 'status',
            width: 100,
            align: 'center',
            render: (value: number) => {
                return (value === 0 ? <Badge status="success" text="已开启" /> : <Badge status="error" text="已关闭" />)
            }
        },
        {
            title: '创建时间',
            key: 'createTime',
            dataIndex: 'createTime',
            width: 200,
            render: (value: number) => {
                return formatDate(new Date(value), "YYYY-mm-dd HH:MM:SS")
            }
        },
        {
            title: t("QkOmYwne" /* 操作 */),
            key: 'action',
            render: (value: PositionVO, record) => (
                <Space size="small" split={( <Divider type='vertical' />)}>
                    <a onClick={() => {
                            seEditPosition(value);
                            seEditorVisable(true);
                        }}>
                        编辑
                    </a>
                    <a onClick={() => {
                            showDeleteConfirm(value)
                        }}>
                        删除
                    </a>
                </Space>
            ),
        },
    ];

    useEffect(() => {
        load();
    }, []);

    const onReset = () => {
        searchFrom.resetFields()
        load()
    }

    return (
        <>
            <div>
                <Card className='mt-[4px] dark:bg-[rgb(33,41,70)] bg-white roundle-lg px[12px]' bodyStyle={{ paddingTop: 4, paddingBottom: 4 }}>
                    <div className='flex justify-between content-center'>
                        <div className='flex justify-normal items-center'>
                        <Form layout='inline' form={searchFrom}>
                                <Form.Item name="name" label="岗位名称">
                                    <Input className='w-[150px]' placeholder='请输入名称' allowClear />
                                </Form.Item>
                                <Form.Item name="code" label="岗位编码">
                                    <Input className='w-[150px]' placeholder='请输入编码' allowClear />
                                </Form.Item>
                                <Form.Item className='ml-2 w-[130px]' name="status" label="状态">
                                    <Select placeholder="请选择" allowClear >
                                        <Select.Option value="">全部</Select.Option>
                                        <Select.Option value="0">开启</Select.Option>
                                        <Select.Option value="1">关闭</Select.Option>
                                    </Select>
                                </Form.Item>
                            </Form>
                            <Space.Compact className="ml-5">
                                <Button type='primary' size='large' icon={<SearchOutlined />} onClick={load}> 搜索 </Button>
                                <Button type='primary' size='large' icon={<UndoOutlined />} onClick={onReset}> 重置 </Button>
                            </Space.Compact>
                        </div>
                        <div className="py-[4px]">
                            <Button className="ml-5" type='primary' size='large' icon={<PlusOutlined />} onClick={() => {
                            seEditPosition(undefined);
                            seEditorVisable(true);
                        }}> 新增岗位 </Button>
                        </div>
                    </div>
                </Card>
                <Card className='mt-[4px] dark:bg-[rgb(33,41,70)] bg-white roundle-lg px[12px]'>
                    <Table rowKey="id"
                        scroll={{ x: true }}
                        columns={columns}
                        dataSource={dataSource}
                        className='bg-transparent'
                        pagination={{ position: ['bottomRight'] }} />
                </Card>
            </div>
            <PositionEditor
                onSave={() => {
                    load();
                    seEditorVisable(false);
                }}
                onCancel={() => { seEditorVisable(false) }}
                visible={editorVisable}
                data={editPosition} />
        </>
    );
};

export default MenuListPage;
