import React, {  useEffect, useState } from 'react'
import { Form, Input, InputNumber, Radio, Modal, Switch } from 'antd';
import roleService from '@/request/service/role';
import { useRequest } from '@/hooks/use-request';
import type { RoleVO } from '@/models'
import { antdUtils } from '@/utils/antd';


const layout = {
    labelCol: { span: 4, },
    wrapperCol: { span: 16 },
    bordered: false,
};

interface RoleEditorProps {
    visible: boolean;
    onCancel: (flag?: boolean) => void;
    onSave: (role: RoleVO) => void;
    data?: RoleVO | null;
}


const RoleEditor: React.FC<RoleEditorProps> = (props) => {

    const { visible, onCancel, onSave, data } = props;

    const { runAsync: updateRole } = useRequest(roleService.updateRole, { manual: true });
    const { runAsync: createRole } = useRequest(roleService.createRole, { manual: true });

    const isEdit = !!data;


    const [saveLoading, setSaveLoading] = useState(false);
    const [form] = Form.useForm();

    useEffect(() => {
        if (visible) {
            if (data) {
                form.setFieldsValue(data);
            }
        } else {
            form.resetFields();
        }
    }, [visible]);

    const save = async () => {
        setSaveLoading(true);
        const fieldValues = form.getFieldsValue();
        const newValue = isEdit ? { ...data, ...fieldValues } : fieldValues;
        const [error, { msg, code }] = isEdit ? await updateRole(newValue) : await createRole(newValue);
        if (!error && code === 0) {
            onSave(newValue);
        } else {
            antdUtils.message?.open({
                type: 'error',
                content: msg ?? '操作失败',
            });
        }
        setSaveLoading(false);
    }

    return (
        <>
            <Modal
                open={visible}
                title={isEdit ? "编辑" : "新建"}
                width={640}
                onOk={save}
                onCancel={() => onCancel()}
                confirmLoading= {saveLoading}
                destroyOnClose
            >
                <Form
                    form={form}
                    {...layout}
                    onFinish={save}
                    labelCol={{ flex: '0 0 100px' }}
                    wrapperCol={{ span: 16 }}
                >
                    <Form.Item name="name" label="角色名称"
                        rules={[
                            {
                                required: true,
                                message: '请输入角色名称',
                            },
                        ]}
                    >
                        <Input />
                    </Form.Item>

                    <Form.Item name="code" label="角色标识"
                        rules={[
                            {
                                required: true,
                                message: '请输入角色标识',
                            },
                        ]}
                    >
                        <Input />
                    </Form.Item>

                    <Form.Item name="sort" label="显示排序" >
                        <InputNumber min={1} max={100} />
                    </Form.Item>

                    <Form.Item name="remark" label="备注" >
                        <Input.TextArea showCount maxLength={100} />
                    </Form.Item>

                    <Form.Item name="status" label="状态">
                        <Radio.Group options={[
                            { value: 0, label: "开启" },
                            { value: 1, label: "关闭" }
                        ]} optionType="default">
                        </Radio.Group>
                    </Form.Item>
                </Form>
            </Modal>
        </>
    )
}

export default RoleEditor;
