import React, { useEffect, useState } from 'react'
import { Form, Input, InputNumber, Radio, Modal, Select, DatePicker } from 'antd';
import tenantService from '@/request/service/tenant';
import tenantPkgService from '@/request/service/tenant-package';
import { useRequest } from '@/hooks/use-request';
import type { TenantVO } from '@/models'
import { antdUtils } from '@/utils/antd';
import customParseFormat from 'dayjs/plugin/customParseFormat';

import dayjs from 'dayjs';
dayjs.extend(customParseFormat);


const layout = {
    labelCol: { span: 4, },
    wrapperCol: { span: 16 }
};

interface EditorProps {
    visible: boolean;
    onCancel: (flag?: boolean) => void;
    onSave: (role: TenantVO) => void;
    data?: TenantVO | null;
}


const TenantEditor: React.FC<EditorProps> = (props) => {

    const { visible, onCancel, onSave, data } = props;

    const { runAsync: updateApi } = useRequest(tenantService.updateTenantApi, { manual: true });
    const { runAsync: createApi } = useRequest(tenantService.createTenantApi, { manual: true });
    const { data: tenanPackages, run: getTenantPackageList } = useRequest(tenantPkgService.getTenantPackageList, { manual: true });

    const isEdit = !!data;


    const [saveLoading, setSaveLoading] = useState(false);
    const [form] = Form.useForm();

    useEffect(() => {
        if (visible) {
            if (data) {
                form.setFieldsValue(data);
                form.setFieldValue('expireTime', dayjs(data.expireTime))
            }
        } else {
            form.resetFields();
        }
    }, [visible]);

    useEffect(() => {
        getTenantPackageList()
    }, [getTenantPackageList])

    const save = async () => {
        setSaveLoading(true);
        const fieldValues = form.getFieldsValue();
        const expireTime = dayjs(form.getFieldValue('expireTime')).toDate().getTime()
        const newValue = isEdit ? { ...data, ...fieldValues, expireTime } : {...fieldValues, expireTime};
        const [error, { msg, code }] = isEdit ? await updateApi(newValue) : await createApi(newValue);
        if (!error && code === 0) {
            onSave(newValue);
        } else {
            antdUtils.message?.open({
                type: 'error',
                content: msg ?? '操作失败',
            });
        }
        setSaveLoading(false);
    }

    return (
        <>
            <Modal
                open={visible}
                title="新建"
                width={640}
                onOk={save}
                onCancel={() => onCancel()}
                confirmLoading= {saveLoading}
                destroyOnClose
            >
                <Form
                    form={form}
                    {...layout}
                    onFinish={save}
                    labelCol={{ flex: '0 0 100px' }}
                    wrapperCol={{ span: 16 }}
                >
                    <Form.Item name="name" label="租户名称"
                        rules={[
                            {
                                required: true,
                                message: '请输入租户名称',
                            },
                        ]}
                    >
                        <Input />
                    </Form.Item>

                    <Form.Item name="packageId" label="租户套餐"
                        rules={[
                            {
                                required: true,
                                message: '请选择租户套餐',
                            },
                        ]}
                    >
                        <Select placeholder="请选择租户套餐" options={tenanPackages?.data.map(item => {
                            return {
                                label: item.name,
                                value: item.id,
                            }
                        })}>
                        </Select>
                    </Form.Item>


                    <Form.Item name="contactName" label="联系人"
                        rules={[
                            {
                                required: true,
                                message: '请输入联系人',
                            },
                        ]}
                    >
                        <Input />
                    </Form.Item>


                    <Form.Item name="contactMobile" label="联系电话"
                        rules={[
                            {
                                required: true,
                                message: '请输入电话号码',
                            },
                        ]}
                    >
                        <Input />
                    </Form.Item>

                    <Form.Item name="username" label="用户名称">
                        <Input />
                    </Form.Item>

                    <Form.Item name="password" label="用户密码">
                        <Input />
                    </Form.Item>

                    <Form.Item name="accountCount" label="账号额度" >
                        <InputNumber min={0} />
                    </Form.Item>

                    <Form.Item name="expireTime" label="过期时间"
                        rules={[
                            {
                                required: true,
                                message: '请设置过期时间',
                            },
                        ]}>
                        <DatePicker showTime format="YYYY-MM-DD HH:mm:ss" />
                    </Form.Item>

                    <Form.Item name="domain" label="绑定域名"
                        rules={[
                            {
                                required: true,
                                message: '请输入绑定域名',
                            },
                        ]}
                    >
                        <Input />
                    </Form.Item>

                    <Form.Item name="status" label="租户状态" rules={[
                            {
                                required: true,
                                message: '请选择租户状态',
                            },
                        ]}>
                        <Radio.Group options={[
                            { value: 0, label: "开启" },
                            { value: 1, label: "关闭" }
                        ]} optionType="default">
                        </Radio.Group>
                    </Form.Item>
                </Form>
            </Modal>
        </>
    )
}

export default TenantEditor;
