import React, { useEffect, useState } from 'react'
import { Form, Input, InputNumber, Radio, Modal, TreeSelect } from 'antd';
import tenantPkgService from '@/request/service/tenant-package';
import menuService from '@/request/service/menu';
import { useRequest } from '@/hooks/use-request';
import type { DefaultOptionType } from 'antd/es/select';
import type { Menu, TenantPackageVO } from '@/models';
import { antdUtils } from '@/utils/antd';

const layout = {
    labelCol: { span: 4, },
    wrapperCol: { span: 16 },
    bordered: false,
};

interface EditorProps {
    visible: boolean;
    onCancel: (flag?: boolean) => void;
    onSave: (role: TenantPackageVO) => void;
    data?: TenantPackageVO | null;
}
const toMenuTree = (data: Menu[]) => {
    const root: Menu[] = data.filter(item => {
        return !data.some(it => it.id === item.parentId)
    });
    const toMenuTreeItem = (item: Menu): DefaultOptionType => {
        return {
            label: item.name,
            value: item.id,
            children: data.filter(it => it.parentId === item.id).map(it => {
                return toMenuTreeItem(it)
            })
        }
    }
    return root.map(item => {
        return toMenuTreeItem(item)
    })
}

const TenantPackageEditor: React.FC<EditorProps> = (props) => {

    const { visible, onCancel, onSave, data } = props;

    const { runAsync: updateApi } = useRequest(tenantPkgService.updateTenantPackageTypeApi, { manual: true });
    const { runAsync: createApi } = useRequest(tenantPkgService.createTenantPackageTypeApi, { manual: true });
    const { data: menus, run: getMenuList } = useRequest(menuService.listSimpleMenusApi, { manual: true });
    // const [value, setValue] = useState(['0-0-0']);

    // const onChange = (newValue: string[]) => {
    //   console.log('onChange ', value);
    //   setValue(newValue);
    // };

    const isEdit = !!data;

    const [saveLoading, setSaveLoading] = useState(false);
    const [form] = Form.useForm();

    useEffect(() => {
        if (visible) {
            if (data) {
                form.setFieldsValue(data);
            }
        } else {
            form.resetFields();
        }
    }, [visible]);

    useEffect(() => {
        getMenuList();
    }, [getMenuList]);

    const save = async () => {
        setSaveLoading(true);
        const fieldValues = form.getFieldsValue();
        const newValue = isEdit ? { ...data, ...fieldValues } : fieldValues;
        const [error, { msg, code }] = isEdit ? await updateApi(newValue) : await createApi(newValue);
        if (!error && code === 0) {
            onSave(newValue);
        } else {
            antdUtils.message?.open({
                type: 'error',
                content: msg ?? '操作失败',
            });
        }
        setSaveLoading(false);
    }

    return (
        <>
            <Modal
                open={visible}
                title="新建"
                width={640}
                onOk={save}
                confirmLoading={saveLoading}
                onCancel={() => onCancel()}
                destroyOnClose
            >
                <Form
                    form={form}
                    {...layout}
                    onFinish={save}
                    labelCol={{ flex: '0 0 100px' }}
                    wrapperCol={{ span: 16 }}
                >
                    <Form.Item name="name" label="套餐名称"
                        rules={[
                            {
                                required: true,
                                message: '请输入套餐名称',
                            },
                        ]}
                    >
                        <Input />
                    </Form.Item>

                    <Form.Item name="menuIds" label="菜单权限" >
                        <TreeSelect
                            multiple
                            treeCheckable
                            showCheckedStrategy= {TreeSelect.SHOW_PARENT}
                            treeData={toMenuTree(menus?.data ?? [])} />
                    </Form.Item>

                    <Form.Item name="remark" label="备注" >
                        <Input.TextArea showCount maxLength={100} />
                    </Form.Item>

                    <Form.Item name="status" label="状态">
                        <Radio.Group options={[
                            { value: 0, label: "开启" },
                            { value: 1, label: "关闭" }
                        ]} optionType="default">
                        </Radio.Group>
                    </Form.Item>
                </Form>
            </Modal>
        </>
    )
}

export default TenantPackageEditor;
